@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.302063';
+our $VERSION = '1.302064';
 
 BEGIN {
     if( $] < 5.008 ) {
@@ -238,6 +238,7 @@ sub finalize {
     my $plan   = $chub->plan || 0;
     my $count  = $chub->count;
     my $failed = $chub->failed;
+    my $passed = $chub->is_passing;
 
     my $num_extra = $plan =~ m/\D/ ? 0 : $count - $plan;
     if ($count && $num_extra != 0) {
@@ -257,6 +258,12 @@ Looks like you failed $failed test$s of $count$qualifier.
 FAIL
     }
 
+    if (!$passed && !$failed && $count && !$num_extra) {
+        $st_ctx->diag(<<"FAIL");
+All assertions inside the subtest passed, but errors were encountered.
+FAIL
+    }
+
     $st_ctx->release;
 
     unless ($chub->bailed_out) {
@@ -1550,6 +1557,7 @@ sub _ending {
     my $plan  = $hub->plan;
     my $count = $hub->count;
     my $failed = $hub->failed;
+    my $passed = $hub->is_passing;
     return unless $plan || $count || $failed;
 
     # Ran tests but never declared a plan or hit done_testing
@@ -1622,6 +1630,12 @@ Looks like you failed $failed test$s of $count$qualifier.
 FAIL
     }
 
+    if (!$passed && !$failed && $count && !$num_extra) {
+        $ctx->diag(<<"FAIL");
+All assertions passed, but errors were encountered.
+FAIL
+    }
+
     my $exit_code = 0;
     if ($failed) {
         $exit_code = $failed <= 254 ? $failed : 254;
@@ -1629,6 +1643,9 @@ FAIL
     elsif ($num_extra != 0) {
         $exit_code = 255;
     }
+    elsif (!$passed) {
+        $exit_code = 255;
+    }
 
     $$new ||= $exit_code;
     return;
